SpiegeLib Subjective Test

Loading...
Loading...
Instructions:

- Use high quality studio headphones and a good soundcard!
- Listen through all test files and test sets before you do any ratings to get used to the material.
- Rate the quality of the test items only compared to the reference on top.
- Try to rate the overall impression of a test item and don't concentrate on single aspects.

You're all done!
We are sorry, but the following error occured during your submission:

Please submit the results. JSON results files will be rendered and saved.

Please download and save the results. Entering a name or email address is not mandatory but it would help us to contact you if we have further questions. You can also leave a comment.

Name: |
Email: |
| Your comment...

Results should be send to

00:00
Loop Auto Return
Volume